@@ -4,7 +4,8 @@ OC.L10N.register(
     "Notes" : "নোট",
     "Error" : "সমস্যা",
     "New note" : "নতুন নোট",
-    "Details" : "বিসতারিত",
+    "Share" : "ভাগাভাগি কর",
+    "Rename" : "Rename",
     "Delete note" : "নোট মোছ",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
