@@ -35,7 +35,8 @@ OC.L10N.register(
     "Wrong image" : "Λάθος εικόνα",
     "The file was not uploaded. Check your server logs." : "Το αρχείο δεν μεταφορτώθηκε. Ελέγξτε τα αρχεία καταγραφής του διακομιστή σας.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Εγκαταστήστε την εφαρμογή στο κινητό σας για πρόσβαση από οπουδήποτε.",
-    "Details" : "Λεπτομέρειες",
+    "Share" : "Κοινή χρήση",
+    "Rename" : "Rename",
     "Delete note" : "Διαγραφή σημείωσης",
     "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
     "Add to favorites" : "Προσθήκη στα αγαπημένα ",
@@ -61,19 +62,8 @@ OC.L10N.register(
     "Last week" : "Προηγούμενη εβδομάδα",
     "This month" : "Αυτό το μήνα",
     "Last month" : "Προηγούμενος μήνας",
-    "Category" : "Κατηγορία",
-    "Uncategorized" : "Χωρίς κατηγορία",
-    "Set category" : "Ορίστε κατηγορία",
-    "Click here to save manually" : "Κλίκ εδώ για χειροκίνητη αποθήκευση",
-    "Saving failed!" : "Απέτυχε η αποθήκευση!",
-    "Last modified: {date}" : "Τελευταία τροποίηση: {date}",
-    "Note has unsaved changes" : "Η σημείωση έχει αλλαγές που δεν έχουν αποθηκευτεί",
-    "Subcategory" : "Υποκατηγορία",
-    "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
-    "_%n character_::_%n characters_" : ["%n χαρακτήρας","%n χαρακτήρες"],
     "Use Markdown markups to style your text." : "Με χρήση του Markdown για να δώσετε στυλ στο κείμενό σας.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Ξεκινήστε μια σημείωση κάνοντας κλικ στο \"{newnote}\" από το μενού εφαρμογών.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Μπορείτε να δημιουργήσετε υποκατηγορίες χρησιμοποιώντας το \"/\" ως οριοθέτη μεταξύ της κατηγορίας και της υποκατηγορίας, π.χ. \"{Parent}/{sub}\".",
     "Note not found." : "Δεν βρέθηκε η σημείωση.",
     "Note is locked." : "Η σημείωση είναι κλειδωμένη.",
     "Insufficient storage." : "Μη επαρκής αποθηκευτικός χώρος.",
@@ -92,6 +82,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Η εναλλαγή του αγαπημένου για τη σημείωση {id} απέτυχε.",
     "Updating the note's category has failed. Is the target directory writable?" : "Η ενημέρωση της κατηγορίας σημείωσης απέτυχε. Ο κατάλογος είναι εγγράψιμος;",
     "Updating the category for note {id} has failed." : "Η ενημέρωση της κατηγορίας σημείωσης {id} απέτυχε.",
+    "Uncategorized" : "Χωρίς κατηγορία",
     "Tasks" : "Εργασίες",
     "Development Mode" : "Κατάσταση προγραμματισμού",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Φαίνεται ότι η εφαρμογή σημειώσεων εγκαταστάθηκε από μια τρίτη πηγή ανάπτυξης. Παρακαλούμε εγκαταστήστε από την επίσημη <a href=\"%1$s\"> Αγορά Εφαρμογών Nextcloud</a>. Αν επιθυμείτε να αναπτύξετε την εφαρμογή Σημειώσεων, παρακαλούμε ακολουθήστε τις <a href=\"%2$s\">οδηγίες προγραμματιστών</a>."
