@@ -5,26 +5,24 @@ OC.L10N.register(
     "Error" : "Error",
     "New note" : "Nota nueva",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "Settings" : "Configuraciones ",
-    "No notes yet" : "Aún no hay notas",
+    "Action" : "Acción",
+    "Open in edit mode" : "Abrir en modo edición",
+    "Open in preview mode" : "Abrir en modo previsualización",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "This week" : "Esta semana",
-    "This month" : "Este mes",
+    "No notes yet" : "Aún no hay notas",
+    "Share" : "Compartir",
     "Rename" : "Renombrar",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
-    "Details" : "Detalles",
     "Edit" : "Editar",
     "Preview" : "Previsualizar",
-    "Category" : "Categoría",
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "This week" : "Esta semana",
+    "This month" : "Este mes",
     "Uncategorized" : "Sin categoría",
-    "Saving failed!" : "¡Falla al guardar!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
-    "Android app" : "Aplicación Android",
-    "iOS app" : "Aplicación iOS"
+    "Tasks" : "Tareas"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
