@@ -2,29 +2,26 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Notas",
-    "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
-    "New note" : "Nota nueva",
-    "Encryption Error" : "Error de encripción",
     "Error" : "Error",
-    "Settings" : "Configuraciones ",
+    "New note" : "Nota nueva",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
+    "Action" : "Acción",
+    "Open in edit mode" : "Abrir en modo edición",
+    "Open in preview mode" : "Abrir en modo previsualización",
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
+    "No notes yet" : "Aún no hay notas",
+    "Share" : "Compartir",
+    "Delete note" : "Borrar nota",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Add to favorites" : "Agregar a tus favoritos",
+    "Edit" : "Editar",
+    "Preview" : "Previsualizar",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
     "This month" : "Este mes",
-    "Delete note" : "Borrar nota",
-    "Remove from favorites" : "Eliminar de favoritos",
-    "Add to favorites" : "Agregar a tus favoritos",
-    "Details" : "Detalles",
-    "Preview" : "Previsualizar",
-    "Edit" : "Editar",
-    "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
-    "Saving failed!" : "¡Falla al guardar!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
-    "Android app" : "Aplicación Android",
-    "iOS app" : "Aplicación iOS"
+    "Tasks" : "Tareas"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
