@@ -13,7 +13,8 @@ OC.L10N.register(
     "All notes" : "Todas las notas",
     "Categories" : "Categorías",
     "No notes yet" : "Aún no hay notas",
-    "Details" : "Detalles",
+    "Share" : "Compartir",
+    "Rename" : "Rename",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
@@ -24,10 +25,7 @@ OC.L10N.register(
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
     "This month" : "Este mes",
-    "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
-    "Saving failed!" : "¡Falla al guardar!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
     "Tasks" : "Tareas"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
