@@ -27,7 +27,8 @@ OC.L10N.register(
     "Categories" : "קטגוריות",
     "No notes yet" : "אין פתקים עדיין",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "יש להתקין את היישומון לטלפון הנייד שלך כדי לגשת לפתקים שלך מכל מקום.",
-    "Details" : "פרטים",
+    "Share" : "Share",
+    "Rename" : "שנה שם",
     "Delete note" : "מחיקת פתק",
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
@@ -49,19 +50,8 @@ OC.L10N.register(
     "Last week" : "שבוע שעבר",
     "This month" : "החודש",
     "Last month" : "חודש שעבר",
-    "Category" : "קטגוריה",
-    "Uncategorized" : "ללא קטגוריה",
-    "Set category" : "הגדרת קטגוריה",
-    "Click here to save manually" : "יש ללחוץ כאן כדי לשמור ידנית",
-    "Saving failed!" : "השמירה נכשלה!",
-    "Last modified: {date}" : "שינוי אחרון: {date}",
-    "Note has unsaved changes" : "יש שינויים בפתק שטרם נשמרו",
-    "Subcategory" : "תת־קטגוריה",
-    "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
-    "_%n character_::_%n characters_" : ["תו אחד","%n תווים","%n תווים","%n תווים"],
     "Use Markdown markups to style your text." : "תמיכה בסימון מסוג Markdown כדי לסגנן את הטקסט שלך.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "ניתן להתחיל לכתוב פתק על ידי לחיצה על „{newnote}” בניווט של היישומון.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "ניתן ליצור תת־קטגוריות על ידי שימוש ב־„/” כמפריד בין קטגוריית ההורה ותת־הקטגוריה, למשל: „‎{parent}/{sub}‎”.",
     "Note not found." : "הפתק לא נמצא.",
     "Note is locked." : "הפתק נעול.",
     "Insufficient storage." : "אין מספיק שטח אחסון.",
@@ -79,6 +69,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "החלפת מצב העדפה לפתק {id} נכשלה.",
     "Updating the note's category has failed. Is the target directory writable?" : "עדכון קטגוריית הפתק נכשלה. האם תיקיית היעד נגישה לכתיבה?",
     "Updating the category for note {id} has failed." : "עדכון הקטגוריה של הפתק {id} נכשלה.",
+    "Uncategorized" : "ללא קטגוריה",
     "Tasks" : "משימות",
     "Development Mode" : "מצב פיתוח"
 },
