@@ -5,7 +5,8 @@ OC.L10N.register(
     "Error" : "Սխալ",
     "New note" : "Նոր նոթ",
     "No notes yet" : "առայժմ գրառում չկա",
-    "Details" : "Մանրամասներ",
+    "Share" : "Կիսվել",
+    "Rename" : "Rename",
     "Delete note" : "Ջնջել նոթը",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
@@ -13,7 +14,6 @@ OC.L10N.register(
     "Today" : "այսօր",
     "Yesterday" : "երեկ",
     "This week" : "այս շաբաթ",
-    "This month" : "այս ամիս",
-    "_%n word_::_%n words_" : ["%n բառ","%n բառ"]
+    "This month" : "այս ամիս"
 },
 "nplurals=2; plural=(n != 1);");
