@@ -13,6 +13,7 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "Ci sono note non salvate. Uscita. Se lasci la pagina perderai tutte le modifiche!",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["Eliminata {number} nota","Eliminate {number} note","Eliminate {number} note"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Ripristinata {number} nota","Ripristinate {number} note","Ripristinate {number} note"],
+    "Basics" : "Nozioni di base",
     "Write down your thoughts without any distractions." : "Annota i tuoi pensieri senza alcuna distrazione.",
     "Organize your notes in categories." : "Organizza le tue note in categorie.",
     "Folder to store your notes" : "Cartella in cui memorizzare le tue note",
@@ -20,10 +21,14 @@ OC.L10N.register(
     "File extension for new notes" : "Estensione dei file per le nuove note",
     "Display mode for notes" : "Modalità di visualizzazione delle note",
     "Shortcuts" : "Scorciatoie",
+    "Shortcut" : "Scorciatoia",
     "Action" : "Azione",
     "User defined" : "Utente definito",
     "Open in edit mode" : "Apri in modalità modifica",
     "Open in preview mode" : "Apri in modalità anteprima",
+    "CTRL" : "CTRL",
+    "ALT" : "ALT",
+    "SHIFT" : "SPOSTARE",
     "Insert image" : "Inserisci immagine",
     "All notes" : "Tutte le note",
     "Categories" : "Categorie",
@@ -34,7 +39,7 @@ OC.L10N.register(
     "Wrong image" : "Immagine errata",
     "The file was not uploaded. Check your server logs." : "Il file non è stato caricato. Controlla i log del tuo server.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa l'applicazione per il tuo cellulare per accedere alle tue note da ovunque.",
-    "Details" : "Dettagli",
+    "Share" : "Condivisione",
     "Delete note" : "Elimina nota",
     "Remove from favorites" : "Rimuovi dai preferiti",
     "Add to favorites" : "Aggiungi ai preferiti",
@@ -60,19 +65,8 @@ OC.L10N.register(
     "Last week" : "Settimana scorsa",
     "This month" : "Questo mese",
     "Last month" : "Mese scorso",
-    "Category" : "Categoria",
-    "Uncategorized" : "Senza categoria",
-    "Set category" : "Imposta categoria",
-    "Click here to save manually" : "Fai clic qui per salvare manualmente",
-    "Saving failed!" : "Salvataggio non riuscito!",
-    "Last modified: {date}" : "Ultima modifica: {date}",
-    "Note has unsaved changes" : "La nota ha modifiche non salvate",
-    "Subcategory" : "Sottocategoria",
-    "_%n word_::_%n words_" : ["%n parola","%n parole","%n parole"],
-    "_%n character_::_%n characters_" : ["%n carattere","%n caratteri","%n caratteri"],
     "Use Markdown markups to style your text." : "Usa contrassegni Markdown per formattare il tuo testo.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Inizia a scrivere una nota facendo clic su \"{newnote}\" nell'applicazione.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Puoi creare sottocategorie utilizzando \"/\" come delimitatore tra la categoria superiore e la sottocategoria, ad. es \"{parent}/{sub}\".",
     "Note not found." : "Nota non trovata.",
     "Note is locked." : "La nota è bloccata.",
     "Insufficient storage." : "Spazio di archiviazione insufficiente.",
@@ -91,7 +85,9 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "L'attivazione come preferito della nota {id} non è riuscita",
     "Updating the note's category has failed. Is the target directory writable?" : "L'aggiornamento della categoria delle note non è riuscito. La cartella di destinazione è scrivibile?",
     "Updating the category for note {id} has failed." : "Aggiornamento della categoria per la nota {id} non riuscito.",
+    "Uncategorized" : "Senza categoria",
     "Tasks" : "Compiti",
+    "Birthdays" : "Compleanni",
     "Quotes" : "Preventivi",
     "Development Mode" : "Modalità di sviluppo",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Sembra che l'applicazione delle note sia stata installata da una sorgente di sviluppo. Installala invece dal <a href=\"%1$s\">Negozio delle applicazioni di Nextcloud</a> ufficiale. Se desideri compilare l'applicazione Note in autonomia, segui le <a href=\"%2$s\">istruzioni per sviluppatori</a>"
