@@ -21,7 +21,8 @@ OC.L10N.register(
     "Categories" : "Категории",
     "No notes yet" : "Сеуште нема забелешки",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирајте ја апликацијата за мобилен телефон за да можете да пристапувате до вашите белешки од секаде.",
-    "Details" : "Детали",
+    "Share" : "Share",
+    "Rename" : "Rename",
     "Delete note" : "Избриши белешка",
     "Remove from favorites" : "Отстрани од фаворити",
     "Add to favorites" : "Додади во фаворити",
@@ -43,19 +44,8 @@ OC.L10N.register(
     "Last week" : "Минатата недела",
     "This month" : "Овој месец",
     "Last month" : "Минатиот месец",
-    "Category" : "Категорија",
-    "Uncategorized" : "Некатегоризирани",
-    "Set category" : "Постави категорија",
-    "Click here to save manually" : "Кликни тука за рачно зачувување",
-    "Saving failed!" : "Неуспешно зачувување!",
-    "Last modified: {date}" : "Скоро изменети: {date}",
-    "Note has unsaved changes" : "Белешката има незачувани промени",
-    "Subcategory" : "Подкатегорија",
-    "_%n word_::_%n words_" : ["%n збор","%n зборови"],
-    "_%n character_::_%n characters_" : ["%n карактер","%n карактери"],
     "Use Markdown markups to style your text." : "Користете ознаки за означување за стилизирање на вашиот текст.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Започнете да пишувате белешка со притискање на “{newnote}” во навигацијата на апликацијата.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Можете да креирате поткатегории со употреба на „/“ како разграничувач помеѓу главната категорија и поткатегоријата, на пр. “{parent}/{sub}”.",
     "Note not found." : "Белешката не е пронајдена.",
     "Note is locked." : "Белешката е заклучена.",
     "Insufficient storage." : "Недоболно простор на складиштето.",
@@ -74,6 +64,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Неуспешно поставување во омилени белешки за белешката {id}.",
     "Updating the note's category has failed. Is the target directory writable?" : "Неуспешно ажурирање на категорија за белешките. Дали во папката може да зачувува?",
     "Updating the category for note {id} has failed." : "Неуспешно ажурирање на категорија за белешката {id}.",
+    "Uncategorized" : "Некатегоризирани",
     "Tasks" : "Задачи",
     "Development Mode" : "Мод за програмери",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Се чини дека апликацијата за белешки е инсталирана од извор за развивање. Ве молиме инсталирајте ја официјалната <a href=\"%1$s\">Nextcloud App Store</a> апликација. Ако сакате сами да ја изградите апликацијата Белешки, следете ја следната <a href=\"%2$s\">документација за развивачи</a>."
