@@ -4,16 +4,14 @@ OC.L10N.register(
     "Notes" : "Notat",
     "Error" : "Feil",
     "New note" : "Nytt notat",
-    "Help" : "Hjelp",
-    "Today" : "I dag",
-    "Yesterday" : "i går",
+    "Share" : "Del",
     "Rename" : "Gje nytt namn",
-    "Details" : "Detaljar",
     "Delete note" : "Slett notat",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "Endra",
-    "Category" : "Kategori",
+    "Today" : "I dag",
+    "Yesterday" : "i går",
     "Tasks" : "Oppgåver"
 },
 "nplurals=2; plural=(n != 1);");
