@@ -23,7 +23,8 @@ OC.L10N.register(
     "Categories" : "Categorias",
     "No notes yet" : "Cap de nòta pel moment",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Installatz l’aplicacion per mobil per accedir a vòstras nòtas de pertot.",
-    "Details" : "Detalhs",
+    "Share" : "Share",
+    "Rename" : "Rename",
     "Delete note" : "Suprimir la nòta",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
@@ -44,20 +45,11 @@ OC.L10N.register(
     "Last week" : "La setmana passada",
     "This month" : "Aqueste mes",
     "Last month" : "Lo mes passat",
-    "Category" : "Categoria",
-    "Uncategorized" : "Sens categoria",
-    "Set category" : "Definir categoria",
-    "Click here to save manually" : "Clicatz aquí per enregistrar manualament",
-    "Saving failed!" : "Fracàs de l'enregistrament !",
-    "Last modified: {date}" : "Darrièra modificacion : {date}",
-    "Note has unsaved changes" : "Nòta amb modificacions pas enregistradas",
-    "Subcategory" : "Soscategoria",
-    "_%n word_::_%n words_" : ["%n mot","%n mots"],
-    "_%n character_::_%n characters_" : ["%n caractèr","%n caractèrs"],
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Començatz d’escriure una nòta en clicant « {newnode} » dins la barra de navegacion.",
     "Note not found." : "Cap de nòta pas trobada.",
     "Note is locked." : "La nòta es verrolhada.",
     "Insufficient storage." : "Espaci d'emmagazinatge insufisent.",
+    "Uncategorized" : "Sens categoria",
     "Tasks" : "Prètzfaches",
     "Development Mode" : "Mòde desvelopament"
 },
