@@ -2,29 +2,55 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Note",
+    "Create new note" : "Creează o notă nouă",
+    "More notes" : "Mai multe notițe",
     "Reading notes from filesystem has failed." : "Citirea notiţelor din sistemul de fişiere a eşuat.",
     "Error" : "Eroare",
     "New note" : "Notă nouă",
     "Distraction-free notes and writing" : "Scrie notiţe fără a fi distras",
+    "Notes settings" : "Setări Note",
     "Please see Nextcloud server log for details." : "Vă rugăm să verificaţi fişierele log de pe serverul Nextcloud pentru mai multe detalii.",
     "Deleted {title}" : "{title} a fost şters",
     "Undo Delete" : "Anulează ștergerea",
     "Note recovered" : "Notiţa a fost recuperată",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Există notiţe nesalvate. Dacă părăsiţi această pagină aceste schimbări vor fi pierdute!",
-    "_Deleted {number} note_::_Deleted {number} notes_" : ["A fost şters %1$d notiţă","Au fost şterse %1$d notiţe","Au fost şterse %1$d de notiţe"],
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["A fost ștearsă {number} notă","Au fost șterse {number} note","Au fost șterse {number} note"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["A fost recuperat {number} notiţă","Au fost recuperate {number} notiţe","Au fost recuperate {number} de notiţe"],
+    "Basics" : "Introducere",
     "Write down your thoughts without any distractions." : "Scrie-ţi gândurile fără orice altă distracţie.",
-    "Organize your notes in categories." : "Organizează-ţi notoţele pe categorii.",
+    "Organize your notes in categories." : "Organizează-ţi notiţele pe categorii.",
+    "Notes path" : "Calea pentru note",
     "Folder to store your notes" : "Dosarul pentru a stoca notiţele tale",
     "Root directory" : "Director rădacină",
+    "File extension" : "Extensie fișier",
     "File extension for new notes" : "Extensia fişierului pentru notiţele noi",
+    "Display mode" : "Mod afișare",
     "Display mode for notes" : "Mod afișare notițe",
+    "Shortcuts" : "Scurtături",
+    "Use shortcuts to quickly navigate this app." : "Folosiți scurtături pentru navigare rapidă",
+    "Shortcut" : "Scurtătură",
+    "Action" : "Acțiune",
+    "Mobile apps" : "Aplicații mobile",
     "User defined" : "Definit de utilizator",
+    "Open in rich text mode" : "Deschide în mod formatat",
     "Open in edit mode" : "Deschide în modul editare",
     "Open in preview mode" : "Deschide în modul de previzualizare ",
+    "Make the selection bold" : "Îngroașă selecția",
+    "Make the selection italic" : "Înclină selecția",
+    "Wrap the selection in quotes" : "Pune selecția în ghilimele",
+    "The selection will be turned into monospace" : "Selecția va fi transformată în monospațiu",
+    "Remove any styles from the selected text" : "Elimină formatarea textului",
+    "Makes the current line a list element" : "Transformă linia în element de listă",
+    "Makes the current line a list element with a number" : "Transformă linia curentă în element de listă numerotată",
+    "Toggle heading for current line" : "Comută nivelul pentru linia curentă",
+    "Set the current line as a big heading" : "Setează linia curentă ca titlu mare",
+    "Insert link" : "Inserează link",
     "Insert image" : "Introdu imagine",
+    "Switch between editor and viewer" : "Comută între editare și vizualizare",
+    "Select folder to link to" : "Selectați folderul pentru link",
     "All notes" : "Toate notițele",
     "Categories" : "Categorii",
+    "Create a sample note with Markdown" : "Creați o notă demo cu Markdown",
     "No notes yet" : "Nu există notițe",
     "Upload image" : "Încarcă imagine",
     "Select an image" : "Selectează o imagine",
@@ -32,10 +58,21 @@ OC.L10N.register(
     "Wrong image" : "Imagine greșită",
     "The file was not uploaded. Check your server logs." : "Imaginea nu a fost încărcată. Verifică fișierele log.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalează alicaţia pentru telefonul tău mobil pentru a-ţi accesa notiţele de oriunde.",
-    "Details" : "Detalii",
+    "Android app: {notes}" : "Aplicație Android: {notes}",
+    "iOS app: {notes}" : "Aplicație iOS: {notes}",
+    "Rich text editor" : "Editor cu formatare",
+    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Acum puteți comuta la editorul cu formatare, ușor de utilizat și intuitiv. Acesta permite editarea fără a afișa marcajele Markdown.",
+    "This option can also be changed later on in the Notes app settings." : "Această opțiune poate fi modificată și din setările aplicației Note",
+    "Keep plain Markdown editor" : "Rămâneți în modul de editare Markdown",
+    "Use rich editor" : "Utilizați editorul cu formatare",
+    "Share" : "Share",
+    "Change category" : "Schimbă categoria",
+    "Rename" : "Rename",
+    "Rename note" : "Redenumește notița",
     "Delete note" : "Şterge nota",
     "Remove from favorites" : "Șterge din favorite",
     "Add to favorites" : "Adăugați la favorite",
+    "Error while renaming note." : "Eroare la redenumirea notiței",
     "Error during preparing note for deletion." : "A apărut o eroare în timpul pregătirii ştergerii notiţei.",
     "The note has been changed in another session. Please choose which version should be saved." : "Această notiţă a fost schimbată în altă sesiune. Vă rugăm să alegeţi ce versiune să fie salvată.",
     "Use version from server" : "Foloseşte versiunea de pe server",
@@ -51,26 +88,17 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Salvarea a eşuat. Click pentru a reîncerca.",
     "Update conflict. Click for resolving manually." : "Actualizează conflictul. Click pentru a resolva manual această problemă.",
     "Error from Nextcloud server: {msg}" : "Eroare din partea severului Nextcloud: {msg}",
+    "Search for notes" : "Căutare note",
     "Loading …" : "Se încarcă…",
+    "Find in all categories" : "Căutare în toate categoriile",
     "Today" : "Azi",
     "Yesterday" : "Ieri",
     "This week" : "Săptămâna asta",
     "Last week" : "Săptămâna trecută ",
     "This month" : "Luna asta",
     "Last month" : "Luna trecută ",
-    "Category" : "Categorie",
-    "Uncategorized" : "Fără categorie ",
-    "Set category" : "Setează categoria",
-    "Click here to save manually" : "Apasă aici pentru a salva manual",
-    "Saving failed!" : "Salvarea a eşuat!",
-    "Last modified: {date}" : "Modificat ultima dată: {date}",
-    "Note has unsaved changes" : "Notiţa are schimbări nesalvate",
-    "Subcategory" : "Subcategorie",
-    "_%n word_::_%n words_" : ["%n cuvânt","%n cuvinte","%n cuvinte"],
-    "_%n character_::_%n characters_" : ["%n caracter","%n caractere","%n de caractere"],
     "Use Markdown markups to style your text." : "Foloseşte limbajul Markdown pentru a-ţi stiliza textul.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Începe a scrie o notiţă prin a apăsa pe \"{newnote}” în navigaţia aplicaţiei.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Poţi creea subcategorii prin folosirea simbolului \"/\" pentru a delimita categoria principală de subcategorie, ex: “{parent}/{sub}”.",
     "Note not found." : "Notița nu a fost găsită.",
     "Note is locked." : "Notiţa este blocată.",
     "Insufficient storage." : "Spaţiu de stocare insuficient.",
@@ -89,7 +117,18 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Adăugarea la favorite a notiţei {id} a eşuat.",
     "Updating the note's category has failed. Is the target directory writable?" : "Actualizarea categoriei notiţei a eşuat. Există permisiunea de a scrie în dosarul ţintă?",
     "Updating the category for note {id} has failed." : "Actualizarea categoriei pentru notiţa {id} a eşuat.",
+    "Uncategorized" : "Fără categorie ",
+    "Sample note" : "Notă demo",
+    "15 January 2021, via Nextcloud Notes" : "15 ianuarie 2021, via Nextcloud Notes",
+    "Me, you, and all our friends!" : "Eu, tu și toți prietenii noștri!",
     "Tasks" : "Sarcini",
+    "Write nice todo lists" : "Scrieți liste de sarcini",
+    "Birthdays" : "Zile de naștere",
+    "Turn PC off" : "Oprește PC",
+    "Turn PC on" : "Pornește PC",
+    "Then call IT" : "Apoi apelează la IT",
+    "Quotes" : "Citate",
+    "Nextcloud, a safe home for all your data" : "Nextcloud, o casă sigură pentru toate datele dumneavoastră",
     "Development Mode" : "Mod dezvoltator",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Se pare că aplicaţia de luat notiţe a fost instalată dintr-o sursă destinată dezvoltatorilor. Vă rugăm să instalaţi aplicaţia oficială de pe <a href=\"%1$s\">Magazinul Play</a>. Dacă doriţi să contruiţi aplicaţia Notes, vă rugăm să urmaţi <a href=\"%2$s\">instrucţiunile pentru dezvoltatori</a>."
 },
