@@ -27,7 +27,7 @@ OC.L10N.register(
     "Categories" : "Categorias",
     "No notes yet" : "Peruna nota ancora",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa s'aplicatzione pro su telefoneddu tuo pro intrare a is notas tuas dae totue.",
-    "Details" : "Detàllios",
+    "Rename" : "Torra a numenare",
     "Delete note" : "Elìmina nota",
     "Remove from favorites" : "Boga·nche dae preferidos",
     "Add to favorites" : "Agiunghe a is preferidos",
@@ -53,19 +53,8 @@ OC.L10N.register(
     "Last week" : "Sa chida colada",
     "This month" : "Custu mese",
     "Last month" : "Su mese passadu",
-    "Category" : "Categoria",
-    "Uncategorized" : "Sena categoria",
-    "Set category" : "Imposta categoria",
-    "Click here to save manually" : "Incarca inoghe pro sarvare a manu",
-    "Saving failed!" : "Sarvamentu faddidu!",
-    "Last modified: {date}" : "Ùrtima modìfica: {date}",
-    "Note has unsaved changes" : "Sa nota tenet modìficas non sarvadas",
-    "Subcategory" : "Sutacategoria",
-    "_%n word_::_%n words_" : ["%n  paràulas ","%n paràulas"],
-    "_%n character_::_%n characters_" : ["%n caràteres","%n caràteres"],
     "Use Markdown markups to style your text." : "Imprea cuntrasignos Markdown pro formatare su testu tuo.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Cumintza a iscrìere una nota incarchende subra de \"{newnote}\" in s'aplicatzione.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Podes creare sutacategorias impreende \"/\" comente tremenàrgiu e sa sutacategoria, pr. es. \"{parent}/{sub}\".",
     "Note not found." : "Nota no agatada.",
     "Note is locked." : "Sa nota est blocada.",
     "Insufficient storage." : "S'ispàtziu de archiviatzione non bastat.",
@@ -84,6 +73,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "S'ativatzione comente preferidu de sa nota {id} faddida",
     "Updating the note's category has failed. Is the target directory writable?" : "S'agiornamentu de sa categoria de is notas faddidu. Sa cartella de destinu faghet a dda iscrìere?",
     "Updating the category for note {id} has failed." : "Agiornamentu de sa categoria pro sa nota {id} est faddidu.",
+    "Uncategorized" : "Sena categoria",
     "Tasks" : "Fainas",
     "Development Mode" : "Modalidade de isvilupu",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Paret chu s'aplicatzione de is notas siat istada installada dae una fonte de isvilupu. Installa·dda imbetzes dae <a href=\"%1$s\">Butega de aplicatziones de Nextcloud</a> ufitziales. Si cheres compilare s'aplicatzione Note in autonomia, sighi is <a href=\"%2$s\">istrutziones pro isvilupadores</a>"
