@@ -2,6 +2,7 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Poznámky",
+    "Create new note" : "Vytvoriť novú poznámku",
     "Reading notes from filesystem has failed." : "Čítanie poznámok zo súborového systému zlyhalo.",
     "Error" : "Chyba",
     "New note" : "Nová poznámka",
@@ -21,8 +22,9 @@ OC.L10N.register(
     "File extension for new notes" : "Prípona súboru pre nové poznámky",
     "Display mode for notes" : "Režim zobrazovania poznámok",
     "Shortcuts" : "Skratky",
+    "Shortcut" : "Skratka",
     "Action" : "Akcia",
-    "User defined" : "Definované uživateľom",
+    "User defined" : "Definované používateľo",
     "Open in edit mode" : "Otvoriť v režime úprav",
     "Open in preview mode" : "Otvoriť v režime ukážky",
     "CTRL" : "CTRL",
@@ -38,7 +40,8 @@ OC.L10N.register(
     "Wrong image" : "Chybný obrázok",
     "The file was not uploaded. Check your server logs." : "Súbor nebol nahraný. Skontrolujte záznam o chybách serveru.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Nainštalujte si aplikáciu pre váš mobil a zoberte si vaše poznámky so sebou kamkoľvek.",
-    "Details" : "Podrobnosti",
+    "Share" : "Sprístupňovať",
+    "Rename" : "Rename",
     "Delete note" : "Zmazať poznámku",
     "Remove from favorites" : "Odstrániť z obľúbených",
     "Add to favorites" : "Pridať do obľúbených",
@@ -57,6 +60,7 @@ OC.L10N.register(
     "Save failed. Click to retry." : "Uloženie zlyhalo. Ťuknutím zopakujete.",
     "Update conflict. Click for resolving manually." : "Konflikt pri aktualizácii. Kliknite pre ručné riešenie problému.",
     "Error from Nextcloud server: {msg}" : "Chyba Nextcloud servera: {msg}",
+    "Search for notes" : "Vyhľadať poznámky",
     "Loading …" : "Načítava sa...",
     "Today" : "Dnes",
     "Yesterday" : "Včera",
@@ -64,19 +68,8 @@ OC.L10N.register(
     "Last week" : "Minulý týždeň",
     "This month" : "Tento mesiac",
     "Last month" : "Minulý mesiac",
-    "Category" : "Kategória",
-    "Uncategorized" : "Nezaradené",
-    "Set category" : "Vybrať kategóriu",
-    "Click here to save manually" : "Kliknite sem pre automatické uloženie",
-    "Saving failed!" : "Ukladanie zlyhalo!",
-    "Last modified: {date}" : "Naposledy zmenené: {date}",
-    "Note has unsaved changes" : "Poznámka má neuložené zmeny",
-    "Subcategory" : "Podkategória",
-    "_%n word_::_%n words_" : ["%n slovo","%n slov","%n slov","%n slov"],
-    "_%n character_::_%n characters_" : ["%n znak","%n znaky","%n znaky","%n znakov"],
     "Use Markdown markups to style your text." : "Použite formát Markdown na formátovanie vášho textu.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Začnite písať poznámku kliknutím na “{newnote}” v menu aplikácie.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Môžete vytvoriť subkategórie tak, že pridáte oddeľovací znak “/” medzi kategóriu a subkategóriu. Príklad: “{parent}/{sub}”",
     "Note not found." : "Poznámky sa nenašli.",
     "Note is locked." : "Poznámka je zamknutá.",
     "Insufficient storage." : "Nedostatočný úložný priestor.",
@@ -95,6 +88,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Zaradenie poznámky {id} do obľúbených zlyhalo.",
     "Updating the note's category has failed. Is the target directory writable?" : "Aktualizácia kategórie poznámky zlyhalo. Je možné do cieľového priečinka zapisovať?",
     "Updating the category for note {id} has failed." : "Aktualizácia kategórie pre poznámku {id} zlyhala.",
+    "Uncategorized" : "Nezaradené",
     "Tasks" : "Úlohy",
     "Birthdays" : "Narodeniny",
     "Quotes" : "Ponuky",
