@@ -4,29 +4,25 @@ OC.L10N.register(
     "Notes" : "Shënime",
     "Error" : "Error",
     "New note" : "Shënim i ri",
-    "Help" : "Ndihmë",
-    "Result" : "Rezultatet",
     "Action" : "Veprim",
     "Open in edit mode" : "Hapur në modalitetin e redaktimit",
     "Open in preview mode" : "Hape në parapamje",
-    "No notes yet" : "Nuk ka shënime",
     "All notes" : "Të gjitha shënimet",
     "Categories" : "Kategoritë",
-    "Today" : "Sot",
-    "Yesterday" : "Dje",
-    "This week" : "Këtë javë",
-    "This month" : "Këtë muaj",
+    "No notes yet" : "Nuk ka shënime",
+    "Share" : "Shpërndaje",
     "Rename" : "Rename",
-    "Details" : "Detajet",
     "Delete note" : "Fshije shënimin",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
     "Use current version" : "Përdor versionin aktual",
     "Edit" : "Përpuno",
     "Preview" : "Parapamje ",
-    "Category" : "Kategori",
+    "Today" : "Sot",
+    "Yesterday" : "Dje",
+    "This week" : "Këtë javë",
+    "This month" : "Këtë muaj",
     "Uncategorized" : "Të pakategorizuara",
-    "_%n word_::_%n words_" : ["%n fjalë","%n fjalë"],
     "Tasks" : "Detyra"
 },
 "nplurals=2; plural=(n != 1);");
