@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "குறிப்புகள்",
     "Error" : "வழு",
-    "Details" : "விவரங்கள்",
+    "Share" : "பகிர்வு",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "தொகுக்க",
